# cd-hit

**DOI:** [10.5281/zenodo.10030642](https://doi.org/10.5281/zenodo.10030642)

## Available Versions
- **Version 4.8.1**
  - [Download](https://zenodo.org/records/10030643/files/cd-hit_4.8.1.img)
  - **MD5:** `85dcf116246a0218620c75feaba7d8b4`
  - **DOI:** [10.5281/zenodo.10030643](https://doi.org/10.5281/zenodo.10030643)
  - **Size:** 217.41 MB
  - **Binaries:** 0 available

## Binaries (10 total)

```cd-hit cd-hit-454 cd-hit-div.pl cd-hit-para.pl cd-hit-2d cd-hit-clstr_2_blm8.pl cd-hit-est cd-hit-2d-para.pl cd-hit-div cd-hit-est-2d```
